@@ -76,7 +76,7 @@ class Reports(BrowserView):
         self.blacklisted_types = blacklisted_types
         super(Reports, self).__init__(context, request)
     
-    def _reportPageViews(self,dateRange,portal_type='',path=''):
+    def _reportPageViews(self,dateRange,portal_type='',path='',**kw):
         session = self.session
         where=[]
         where.append(PageView.access_datetime.between(*dateRange))
@@ -88,13 +88,14 @@ class Reports(BrowserView):
         pvs = session.query(func.count('*'),PageView.object_uid).filter(where).order_by(desc(func.count('*'))).group_by(PageView.object_uid)
         listPvs = pvs.all()
         uids = [uid for (pv,uid) in pvs]
-        dictByUIDs = self.dictByUIDs(uids)
+        dictByUIDs = self.dictByUIDs(uids,**kw)
         return [(uid,dictByUIDs[uid].get('Title'),dictByUIDs[uid].get('url'),pv) for (pv,uid) in listPvs if dictByUIDs.get(uid,None)]
     
-    def dictByUIDs(self,uids):
+    def dictByUIDs(self,uids,**kw):
         ct = self.ct
         blacklisted = self.blacklisted_types
-        results = ct.unrestrictedSearchResults(UID={'query':uids})
+        kw['UID'] = UID={'query':uids}
+        results = ct.unrestrictedSearchResults(**kw)
         dictByUIDs = dict([(brain.UID,{'Title':brain.Title,
                                       'path':brain.getPath(),
                                       'url':brain.getURL(),
@@ -233,29 +234,29 @@ class Reports(BrowserView):
         return (start,end)
         
     
-    def viewsLastHour(self):
+    def viewsLastHour(self,**kw):
         range = self.lastHour
-        return self._reportPageViews(range)
+        return self._reportPageViews(range,**kw)
     
-    def viewsLastDay(self):
+    def viewsLastDay(self,**kw):
         range = self.lastDay
-        return self._reportPageViews(range)
+        return self._reportPageViews(range,**kw)
     
-    def viewsLastWeek(self):
+    def viewsLastWeek(self,**kw):
         range = self.lastWeek
-        return self._reportPageViews(range)
+        return self._reportPageViews(range,**kw)
     
-    def viewsLastMonth(self):
+    def viewsLastMonth(self,**kw):
         range = self.lastMonth
-        return self._reportPageViews(range)
+        return self._reportPageViews(range,**kw)
     
-    def viewsLastYear(self):
+    def viewsLastYear(self,**kw):
         range = self.lastYear
-        return self._reportPageViews(range)
+        return self._reportPageViews(range,**kw)
     
-    def viewsAllTime(self):
+    def viewsAllTime(self,**kw):
         range = self.allTime
-        return self._reportPageViews(range)
+        return self._reportPageViews(range,**kw)
     
 
 
